FrameClauseStartBound

Trait FrameClauseStartBound 

pub trait FrameClauseStartBound: Sealed { }
A marker trait for possible start frame expressions

See the list of types implementing this trait to understand what can be used in this position

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors